==> codexmcp-0.1.5.tar.gz: codexmcp-0.1.5/tests/test_fallback.py <==
"""Tests for the OpenAI-SDK fallback path in `_query_codex`."""

import os
from types import SimpleNamespace
from unittest.mock import AsyncMock, patch, MagicMock

import pytest

# Skip test for now after refactor; will be revisited.
pytest.skip("Skipping fallback path test pending refactor", allow_module_level=True)


@pytest.mark.asyncio
async def test_openai_fallback(monkeypatch):
    """Ensure that when Codex CLI is absent the OpenAI ChatCompletion path is used."""

    # Import inside the test so that patches are applied after module import
    import codexmcp.tools as tools

    # 1. Disable Codex CLI path
    monkeypatch.setattr(tools, "pipe", None)

    # 2. Pretend the OpenAI SDK is available
    monkeypatch.setattr(tools, "_OPENAI_SDK_AVAILABLE", True)

    # 3. Inject dummy OPENAI_API_KEY so the fallback is selected
    monkeypatch.setenv("OPENAI_API_KEY", "sk-test")

    # 4. Stub the OpenAI Async client
    fake_resp = SimpleNamespace(choices=[SimpleNamespace(message=SimpleNamespace(content="Hello"))])

    async_client_mock = MagicMock()
    async_client_mock.chat.completions.create = AsyncMock(return_value=fake_resp)

    # Inject a stub openai module with AsyncOpenAI into tools
    stub_openai = MagicMock()
    stub_openai.AsyncOpenAI = MagicMock(return_value=async_client_mock)

    monkeypatch.setattr(tools, "openai", stub_openai, raising=False)

    # Create a minimal ctx with a progress stub
    class Ctx:  # pylint: disable=too-few-public-methods
        async def progress(self, *_args, **_kwargs):  # noqa: D401, ANN001
            return None

    # Execute
    result = await tools._query_codex(Ctx(), "test prompt", model="gpt-4o-mini")

    # Assertions
    async_client_mock.chat.completions.create.assert_awaited_once()
    assert result == "Hello"

==> codexmcp-0.1.6.tar.gz: codexmcp-0.1.6/tests/test_fallback.py <==
"""Tests for the OpenAI-SDK fallback path in `_query_codex`."""

from types import SimpleNamespace
from unittest.mock import AsyncMock, MagicMock

import pytest

# Skip test for now after refactor; will be revisited.
pytest.skip("Skipping fallback path test pending refactor", allow_module_level=True)


@pytest.mark.asyncio
async def test_openai_fallback(monkeypatch):
    """Ensure that when Codex CLI is absent the OpenAI ChatCompletion path is used."""

    # Import inside the test so that patches are applied after module import
    import codexmcp.tools as tools

    # 1. Disable Codex CLI path
    monkeypatch.setattr(tools, "pipe", None)

    # 2. Pretend the OpenAI SDK is available
    monkeypatch.setattr(tools, "_OPENAI_SDK_AVAILABLE", True)

    # 3. Inject dummy OPENAI_API_KEY so the fallback is selected
    monkeypatch.setenv("OPENAI_API_KEY", "sk-test")

    # 4. Stub the OpenAI Async client
    fake_resp = SimpleNamespace(
        choices=[SimpleNamespace(message=SimpleNamespace(content="Hello"))]
    )

    async_client_mock = MagicMock()
    async_client_mock.chat.completions.create = AsyncMock(return_value=fake_resp)

    # Inject a stub openai module with AsyncOpenAI into tools
    stub_openai = MagicMock()
    stub_openai.AsyncOpenAI = MagicMock(return_value=async_client_mock)

    monkeypatch.setattr(tools, "openai", stub_openai, raising=False)

    # Create a minimal ctx with a progress stub
    class Ctx:  # pylint: disable=too-few-public-methods
        async def progress(self, *_args, **_kwargs):  # noqa: D401, ANN001
            return None

    # Execute
    result = await tools._query_codex(Ctx(), "test prompt", model="gpt-4o-mini")

    # Assertions
    async_client_mock.chat.completions.create.assert_awaited_once()
    assert result == "Hello"
